@@ -27,7 +27,6 @@
 #include <stdio.h>
 #include <time.h>
 
-#include <dbus/dbus.h>
 #include <glib.h>
 #include <gdbus.h>
 
@@ -35,8 +34,6 @@
 
 #include "driver.h"
 #include "common.h"
-#include "dbus-gsm.h"
-#include "modem.h"
 
 #define CALL_METER_INTERFACE "org.ofono.CallMeter"
 
@@ -77,11 +74,11 @@ static void set_call_meter(struct ofono_modem *modem, int value)
 	struct call_meter_data *cm = modem->call_meter;
 
 	if (cm->call_meter != value) {
-		DBusConnection *conn = dbus_gsm_connection();
+		DBusConnection *conn = ofono_dbus_get_connection();
 
 		cm->call_meter = value;
 
-		dbus_gsm_signal_property_changed(conn, modem->path,
+		ofono_dbus_signal_property_changed(conn, modem->path,
 							CALL_METER_INTERFACE,
 							"CallMeter",
 							DBUS_TYPE_UINT32,
@@ -94,11 +91,11 @@ static void set_acm(struct ofono_modem *modem, int value)
 	struct call_meter_data *cm = modem->call_meter;
 
 	if (cm->acm != value) {
-		DBusConnection *conn = dbus_gsm_connection();
+		DBusConnection *conn = ofono_dbus_get_connection();
 
 		cm->acm = value;
 
-		dbus_gsm_signal_property_changed(conn, modem->path,
+		ofono_dbus_signal_property_changed(conn, modem->path,
 							CALL_METER_INTERFACE,
 							"AccumulatedCallMeter",
 							DBUS_TYPE_UINT32,
@@ -111,11 +108,11 @@ static void set_acm_max(struct ofono_modem *modem, int value)
 	struct call_meter_data *cm = modem->call_meter;
 
 	if (cm->acm_max != value) {
-		DBusConnection *conn = dbus_gsm_connection();
+		DBusConnection *conn = ofono_dbus_get_connection();
 
 		cm->acm_max = value;
 
-		dbus_gsm_signal_property_changed(conn, modem->path,
+		ofono_dbus_signal_property_changed(conn, modem->path,
 							CALL_METER_INTERFACE,
 							"AccumulatedCallMeterMaximum",
 							DBUS_TYPE_UINT32,
@@ -128,11 +125,11 @@ static void set_ppu(struct ofono_modem *modem, double value)
 	struct call_meter_data *cm = modem->call_meter;
 
 	if (cm->ppu != value) {
-		DBusConnection *conn = dbus_gsm_connection();
+		DBusConnection *conn = ofono_dbus_get_connection();
 
 		cm->ppu = value;
 
-		dbus_gsm_signal_property_changed(conn, modem->path,
+		ofono_dbus_signal_property_changed(conn, modem->path,
 							CALL_METER_INTERFACE,
 							"PricePerUnit",
 							DBUS_TYPE_DOUBLE,
@@ -150,13 +147,13 @@ static void set_currency(struct ofono_modem *modem, const char *value)
 	}
 
 	if (strcmp(cm->currency, value)) {
-		DBusConnection *conn = dbus_gsm_connection();
+		DBusConnection *conn = ofono_dbus_get_connection();
 		const char *dbusval = cm->currency;
 
 		strncpy(cm->currency, value, 3);
 		cm->currency[3] = '\0';
 
-		dbus_gsm_signal_property_changed(conn, modem->path,
+		ofono_dbus_signal_property_changed(conn, modem->path,
 							CALL_METER_INTERFACE,
 							"Currency",
 							DBUS_TYPE_STRING,
@@ -178,24 +175,25 @@ static void cm_get_properties_reply(struct ofono_modem *modem)
 	dbus_message_iter_init_append(reply, &iter);
 
 	dbus_message_iter_open_container(&iter, DBUS_TYPE_ARRAY,
-			PROPERTIES_ARRAY_SIGNATURE, &dict);
+					OFONO_PROPERTIES_ARRAY_SIGNATURE,
+					&dict);
 
-	dbus_gsm_dict_append(&dict, "CallMeter", DBUS_TYPE_UINT32,
+	ofono_dbus_dict_append(&dict, "CallMeter", DBUS_TYPE_UINT32,
 				&cm->call_meter);
 
-	dbus_gsm_dict_append(&dict, "AccumulatedCallMeter", DBUS_TYPE_UINT32,
+	ofono_dbus_dict_append(&dict, "AccumulatedCallMeter", DBUS_TYPE_UINT32,
 				&cm->acm);
 
-	dbus_gsm_dict_append(&dict, "AccumulatedCallMeterMaximum",
+	ofono_dbus_dict_append(&dict, "AccumulatedCallMeterMaximum",
 				DBUS_TYPE_UINT32, &cm->acm_max);
 
-	dbus_gsm_dict_append(&dict, "PricePerUnit", DBUS_TYPE_DOUBLE, &cm->ppu);
+	ofono_dbus_dict_append(&dict, "PricePerUnit", DBUS_TYPE_DOUBLE, &cm->ppu);
 
-	dbus_gsm_dict_append(&dict, "Currency", DBUS_TYPE_STRING, &currency);
+	ofono_dbus_dict_append(&dict, "Currency", DBUS_TYPE_STRING, &currency);
 
 	dbus_message_iter_close_container(&iter, &dict);
 
-	dbus_gsm_pending_reply(&cm->pending, reply);
+	__ofono_dbus_pending_reply(&cm->pending, reply);
 }
 
 static void query_call_meter_callback(const struct ofono_error *error, int value,
@@ -211,21 +209,18 @@ static void query_call_meter_callback(const struct ofono_error *error, int value
 		cm_get_properties_reply(modem);
 }
 
-static gboolean query_call_meter(gpointer user)
+static void query_call_meter(struct ofono_modem *modem)
 {
-	struct ofono_modem *modem = user;
 	struct call_meter_data *cm = modem->call_meter;
 
 	if (!cm->ops->call_meter_query) {
 		if (cm->pending)
 			cm_get_properties_reply(modem);
 
-		return FALSE;
+		return;
 	}
 
 	cm->ops->call_meter_query(modem, query_call_meter_callback, modem);
-
-	return FALSE;
 }
 
 static void query_acm_callback(const struct ofono_error *error, int value,
@@ -236,22 +231,19 @@ static void query_acm_callback(const struct ofono_error *error, int value,
 	if (error->type == OFONO_ERROR_TYPE_NO_ERROR)
 		set_acm(modem, value);
 
-	g_timeout_add(0, query_call_meter, modem);
+	query_call_meter(modem);
 }
 
-static gboolean query_acm(gpointer user)
+static void query_acm(struct ofono_modem *modem)
 {
-	struct ofono_modem *modem = user;
 	struct call_meter_data *cm = modem->call_meter;
 
 	if (!cm->ops->acm_query) {
 		query_call_meter(modem);
-		return FALSE;
+		return;
 	}
 
 	cm->ops->acm_query(modem, query_acm_callback, modem);
-
-	return FALSE;
 }
 
 static void query_acm_max_callback(const struct ofono_error *error, int value,
@@ -265,24 +257,21 @@ static void query_acm_max_callback(const struct ofono_error *error, int value,
 
 	cm->flags |= CALL_METER_FLAG_CACHED;
 
-	g_timeout_add(0, query_acm, modem);
+	query_acm(modem);
 }
 
-static gboolean query_acm_max(gpointer user)
+static void query_acm_max(struct ofono_modem *modem)
 {
-	struct ofono_modem *modem = user;
 	struct call_meter_data *cm = modem->call_meter;
 
 	if (!cm->ops->acm_max_query) {
 		cm->flags |= CALL_METER_FLAG_CACHED;
 
 		query_acm(modem);
-		return FALSE;
+		return; 
 	}
 
 	cm->ops->acm_max_query(modem, query_acm_max_callback, modem);
-
-	return FALSE;
 }
 
 static void query_puct_callback(const struct ofono_error *error,
@@ -297,22 +286,17 @@ static void query_puct_callback(const struct ofono_error *error,
 		set_ppu(modem, ppu);
 	}
 
-	g_timeout_add(0, query_acm_max, modem);
+	query_acm_max(modem);
 }
 
-static gboolean query_puct(gpointer user)
+static void query_puct(struct ofono_modem *modem)
 {
-	struct ofono_modem *modem = user;
 	struct call_meter_data *cm = modem->call_meter;
 
-	if (!cm->ops->puct_query) {
+	if (!cm->ops->puct_query)
 		query_acm_max(modem);
-		return FALSE;
-	}
-
-	cm->ops->puct_query(modem, query_puct_callback, modem);
-
-	return FALSE;
+	else
+		cm->ops->puct_query(modem, query_puct_callback, modem);
 }
 
 static DBusMessage *cm_get_properties(DBusConnection *conn, DBusMessage *msg,
@@ -322,7 +306,7 @@ static DBusMessage *cm_get_properties(DBusConnection *conn, DBusMessage *msg,
 	struct call_meter_data *cm = modem->call_meter;
 
 	if (cm->pending)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	cm->pending = dbus_message_ref(msg);
 
@@ -354,13 +338,13 @@ static void set_acm_max_query_callback(const struct ofono_error *error, int valu
 
 		cm->flags &= ~CALL_METER_FLAG_CACHED;
 
-		dbus_gsm_pending_reply(&cm->pending,
-					dbus_gsm_failed(cm->pending));
+		__ofono_dbus_pending_reply(&cm->pending,
+					__ofono_error_failed(cm->pending));
 		return;
 	}
 
 	reply = dbus_message_new_method_return(cm->pending);
-	dbus_gsm_pending_reply(&cm->pending, reply);
+	__ofono_dbus_pending_reply(&cm->pending, reply);
 
 	set_acm_max(modem, value);
 }
@@ -372,8 +356,8 @@ static void set_acm_max_callback(const struct ofono_error *error, void *data)
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
 		ofono_debug("Setting acm_max failed");
-		dbus_gsm_pending_reply(&cm->pending,
-					dbus_gsm_failed(cm->pending));
+		__ofono_dbus_pending_reply(&cm->pending,
+					__ofono_error_failed(cm->pending));
 		return;
 	}
 
@@ -389,7 +373,7 @@ static DBusMessage *prop_set_acm_max(DBusMessage *msg, struct ofono_modem *modem
 	dbus_uint32_t value;
 
 	if (!cm->ops->acm_max_set)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	dbus_message_iter_get_basic(dbus_value, &value);
 
@@ -416,13 +400,13 @@ static void set_puct_query_callback(const struct ofono_error *error,
 
 		cm->flags &= ~CALL_METER_FLAG_CACHED;
 
-		dbus_gsm_pending_reply(&cm->pending,
-					dbus_gsm_failed(cm->pending));
+		__ofono_dbus_pending_reply(&cm->pending,
+					__ofono_error_failed(cm->pending));
 		return;
 	}
 
 	reply = dbus_message_new_method_return(cm->pending);
-	dbus_gsm_pending_reply(&cm->pending, reply);
+	__ofono_dbus_pending_reply(&cm->pending, reply);
 
 	set_currency(modem, currency);
 	set_ppu(modem, ppu);
@@ -435,8 +419,8 @@ static void set_puct_callback(const struct ofono_error *error, void *data)
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
 		ofono_debug("setting puct failed");
-		dbus_gsm_pending_reply(&cm->pending,
-					dbus_gsm_failed(cm->pending));
+		__ofono_dbus_pending_reply(&cm->pending,
+					__ofono_error_failed(cm->pending));
 		return;
 	}
 
@@ -462,8 +446,8 @@ static void set_puct_initial_query_callback(const struct ofono_error *error,
 		return;
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
-		dbus_gsm_pending_reply(&cm->pending,
-					dbus_gsm_failed(cm->pending));
+		__ofono_dbus_pending_reply(&cm->pending,
+					__ofono_error_failed(cm->pending));
 		return;
 	}
 
@@ -495,12 +479,12 @@ static DBusMessage *prop_set_ppu(DBusMessage *msg, struct ofono_modem *modem,
 	double ppu;
 
 	if (!cm->ops->puct_set || !cm->ops->puct_query)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	dbus_message_iter_get_basic(var, &ppu);
 
 	if (ppu < 0.0)
-		return dbus_gsm_invalid_format(msg);
+		return __ofono_error_invalid_format(msg);
 
 	cm->pending = dbus_message_ref(msg);
 
@@ -521,12 +505,12 @@ static DBusMessage *prop_set_cur(DBusMessage *msg, struct ofono_modem *modem,
 	const char *value;
 
 	if (!cm->ops->puct_set || !cm->ops->puct_query)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	dbus_message_iter_get_basic(var, &value);
 
 	if (strlen(value) > 3)
-		return dbus_gsm_invalid_format(msg);
+		return __ofono_error_invalid_format(msg);
 
 	cm->pending = dbus_message_ref(msg);
 
@@ -565,45 +549,45 @@ static DBusMessage *cm_set_property(DBusConnection *conn, DBusMessage *msg,
 	struct call_meter_property *property;
 
 	if (cm->pending)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (!dbus_message_iter_init(msg, &iter))
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	if (dbus_message_iter_get_arg_type(&iter) != DBUS_TYPE_STRING)
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	dbus_message_iter_get_basic(&iter, &name);
 
 	dbus_message_iter_next(&iter);
 
 	if (dbus_message_iter_get_arg_type(&iter) != DBUS_TYPE_VARIANT)
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	dbus_message_iter_recurse(&iter, &var);
 
 	if (!dbus_message_iter_next(&iter))
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	if (dbus_message_iter_get_arg_type(&iter) != DBUS_TYPE_STRING)
-			return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	dbus_message_iter_get_basic(&iter, &passwd);
 
 	if (!is_valid_pin(passwd))
-		return dbus_gsm_invalid_format(msg);
+		return __ofono_error_invalid_format(msg);
 
 	for (property = cm_properties; property->name; property++) {
 		if (strcmp(name, property->name))
 			continue;
 
 		if (dbus_message_iter_get_arg_type(&var) != property->type)
-			return dbus_gsm_invalid_format(msg);
+			return __ofono_error_invalid_args(msg);
 
 		return property->set(msg, modem, &var, passwd);
 	}
 
-	return dbus_gsm_invalid_args(msg);
+	return __ofono_error_invalid_args(msg);
 }
 
 static void reset_acm_query_callback(const struct ofono_error *error, int value,
@@ -621,13 +605,13 @@ static void reset_acm_query_callback(const struct ofono_error *error, int value,
 
 		cm->flags &= ~CALL_METER_FLAG_CACHED;
 
-		dbus_gsm_pending_reply(&cm->pending,
-					dbus_gsm_failed(cm->pending));
+		__ofono_dbus_pending_reply(&cm->pending,
+					__ofono_error_failed(cm->pending));
 		return;
 	}
 
 	reply = dbus_message_new_method_return(cm->pending);
-	dbus_gsm_pending_reply(&cm->pending, reply);
+	__ofono_dbus_pending_reply(&cm->pending, reply);
 
 	set_acm(modem, value);
 }
@@ -639,8 +623,8 @@ static void acm_reset_callback(const struct ofono_error *error, void *data)
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
 		ofono_debug("reseting acm failed");
-		dbus_gsm_pending_reply(&cm->pending,
-					dbus_gsm_failed(cm->pending));
+		__ofono_dbus_pending_reply(&cm->pending,
+					__ofono_error_failed(cm->pending));
 		return;
 	}
 
@@ -657,21 +641,21 @@ static DBusMessage *cm_acm_reset(DBusConnection *conn, DBusMessage *msg,
 	const char *pin2;
 
 	if (cm->pending)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (!dbus_message_iter_init(msg, &iter))
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	if (dbus_message_iter_get_arg_type(&iter) != DBUS_TYPE_STRING)
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	dbus_message_iter_get_basic(&iter, &pin2);
 
 	if (!is_valid_pin(pin2))
-		return dbus_gsm_invalid_format(msg);
+		return __ofono_error_invalid_format(msg);
 
 	if (!cm->ops->acm_reset)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	cm->pending = dbus_message_ref(msg);
 
@@ -703,7 +687,7 @@ void ofono_call_meter_changed_notify(struct ofono_modem *modem, int new_value)
 
 void ofono_call_meter_maximum_notify(struct ofono_modem *modem)
 {
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	DBusMessage *signal;
 
 	signal = dbus_message_new_signal(modem->path,
@@ -720,7 +704,7 @@ void ofono_call_meter_maximum_notify(struct ofono_modem *modem)
 int ofono_call_meter_register(struct ofono_modem *modem,
 				struct ofono_call_meter_ops *ops)
 {
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 
 	if (!modem || !ops)
 		return -1;
@@ -742,19 +726,19 @@ int ofono_call_meter_register(struct ofono_modem *modem,
 		return -1;
 	}
 
-	modem_add_interface(modem, CALL_METER_INTERFACE);
+	ofono_modem_add_interface(modem, CALL_METER_INTERFACE);
 
 	return 0;
 }
 
 void ofono_call_meter_unregister(struct ofono_modem *modem)
 {
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 
 	if (!modem->call_meter)
 		return;
 
-	modem_remove_interface(modem, CALL_METER_INTERFACE);
+	ofono_modem_remove_interface(modem, CALL_METER_INTERFACE);
 	g_dbus_unregister_interface(conn, modem->path, CALL_METER_INTERFACE);
 
 	modem->call_meter = NULL;
