@@ -31,6 +31,8 @@
 #include "util.h"
 #include "smsutil.h"
 
+#define uninitialized_var(x) x = x
+
 void extract_bcd_number(const unsigned char *buf, int len, char *out)
 {
 	static const char digit_lut[] = "0123456789*#abc\0";
@@ -108,6 +110,17 @@ static inline int to_semi_oct(char in)
 	return digit;
 }
 
+void encode_bcd_number(const char *number, unsigned char *out)
+{
+	while (number[0] != '\0' && number[1] != '\0') {
+		*out = to_semi_oct(*number++);
+		*out++ |= to_semi_oct(*number++) << 4;
+	}
+
+	if (*number)
+		*out = to_semi_oct(*number) | 0xf0;
+}
+
 /* Returns whether the DCS could be parsed successfully, e.g. no reserved
  * values were used
  */
@@ -444,8 +457,8 @@ static gboolean encode_validity_period(const struct sms_validity_period *vp,
 	return FALSE;
 }
 
-static gboolean encode_address(const struct sms_address *in, gboolean sc,
-				unsigned char *pdu, int *offset)
+gboolean sms_encode_address_field(const struct sms_address *in, gboolean sc,
+					unsigned char *pdu, int *offset)
 {
 	size_t len = strlen(in->address);
 	unsigned char addr_len = 0;
@@ -531,14 +544,13 @@ out:
 	return TRUE;
 }
 
-static gboolean decode_address(const unsigned char *pdu, int len,
-				int *offset, gboolean sc,
-				struct sms_address *out)
+gboolean sms_decode_address_field(const unsigned char *pdu, int len,
+					int *offset, gboolean sc,
+					struct sms_address *out)
 {
 	unsigned char addr_len;
 	unsigned char addr_type;
 	int byte_len;
-	int i;
 
 	if (!next_octet(pdu, len, offset, &addr_len))
 		return FALSE;
@@ -563,7 +575,7 @@ static gboolean decode_address(const unsigned char *pdu, int len,
 	out->numbering_plan = bit_field(addr_type, 0, 4);
 
 	if (out->number_type != SMS_NUMBER_TYPE_ALPHANUMERIC) {
-		extract_bcd_number(pdu+*offset, byte_len, out->address);
+		extract_bcd_number(pdu + *offset, byte_len, out->address);
 		*offset += byte_len;
 	} else {
 		int chars;
@@ -634,7 +646,7 @@ static gboolean encode_deliver(const struct sms_deliver *in, unsigned char *pdu,
 
 	set_octet(pdu, offset, oct);
 
-	if (encode_address(&in->oaddr, FALSE, pdu, offset) == FALSE)
+	if (sms_encode_address_field(&in->oaddr, FALSE, pdu, offset) == FALSE)
 		return FALSE;
 
 	set_octet(pdu, offset, in->pid);
@@ -671,7 +683,8 @@ static gboolean decode_deliver(const unsigned char *pdu, int len,
 	out->deliver.udhi = is_bit_set(octet, 6);
 	out->deliver.rp = is_bit_set(octet, 7);
 
-	if (!decode_address(pdu, len, &offset, FALSE, &out->deliver.oaddr))
+	if (!sms_decode_address_field(pdu, len, &offset,
+					FALSE, &out->deliver.oaddr))
 		return FALSE;
 
 	if (!next_octet(pdu, len, &offset, &out->deliver.pid))
@@ -882,7 +895,7 @@ static gboolean encode_status_report(const struct sms_status_report *in,
 
 	set_octet(pdu, offset, in->mr);
 
-	if (!encode_address(&in->raddr, FALSE, pdu, offset))
+	if (!sms_encode_address_field(&in->raddr, FALSE, pdu, offset))
 		return FALSE;
 
 	if (!encode_scts(&in->scts, pdu, offset))
@@ -934,8 +947,8 @@ static gboolean decode_status_report(const unsigned char *pdu, int len,
 	if (!next_octet(pdu, len, &offset, &out->status_report.mr))
 		return FALSE;
 
-	if (!decode_address(pdu, len, &offset, FALSE,
-				&out->status_report.raddr))
+	if (!sms_decode_address_field(pdu, len, &offset, FALSE,
+					&out->status_report.raddr))
 		return FALSE;
 
 	if (!decode_scts(pdu, len, &offset, &out->status_report.scts))
@@ -1172,7 +1185,7 @@ static gboolean encode_submit(const struct sms_submit *in,
 
 	set_octet(pdu, offset, in->mr);
 
-	if (encode_address(&in->daddr, FALSE, pdu, offset) == FALSE)
+	if (sms_encode_address_field(&in->daddr, FALSE, pdu, offset) == FALSE)
 		return FALSE;
 
 	set_octet(pdu, offset, in->pid);
@@ -1214,7 +1227,8 @@ static gboolean decode_submit(const unsigned char *pdu, int len,
 	if (!next_octet(pdu, len, &offset, &out->submit.mr))
 		return FALSE;
 
-	if (!decode_address(pdu, len, &offset, FALSE, &out->submit.daddr))
+	if (!sms_decode_address_field(pdu, len, &offset,
+					FALSE, &out->submit.daddr))
 		return FALSE;
 
 	if (!next_octet(pdu, len, &offset, &out->submit.pid))
@@ -1264,7 +1278,7 @@ static gboolean encode_command(const struct sms_command *in,
 
 	set_octet(pdu, offset, in->mn);
 
-	if (!encode_address(&in->daddr, FALSE, pdu, offset))
+	if (!sms_encode_address_field(&in->daddr, FALSE, pdu, offset))
 		return FALSE;
 
 	set_octet(pdu, offset, in->cdl);
@@ -1304,7 +1318,8 @@ static gboolean decode_command(const unsigned char *pdu, int len,
 	if (!next_octet(pdu, len, &offset, &out->command.mn))
 		return FALSE;
 
-	if (!decode_address(pdu, len, &offset, FALSE, &out->command.daddr))
+	if (!sms_decode_address_field(pdu, len, &offset,
+					FALSE, &out->command.daddr))
 		return FALSE;
 
 	if (!next_octet(pdu, len, &offset, &out->command.cdl))
@@ -1327,7 +1342,7 @@ gboolean sms_encode(const struct sms *in, int *len, int *tpdu_len,
 
 	if (in->type == SMS_TYPE_DELIVER || in->type == SMS_TYPE_SUBMIT ||
 			in->type == SMS_TYPE_COMMAND)
-		if (!encode_address(&in->sc_addr, TRUE, pdu, &offset))
+		if (!sms_encode_address_field(&in->sc_addr, TRUE, pdu, &offset))
 			return FALSE;
 
 	tpdu_start = offset;
@@ -1395,7 +1410,8 @@ gboolean sms_decode(const unsigned char *pdu, int len, gboolean outgoing,
 		return FALSE;
 
 	if (tpdu_len < len) {
-		if (!decode_address(pdu, len, &offset, TRUE, &out->sc_addr))
+		if (!sms_decode_address_field(pdu, len, &offset,
+						TRUE, &out->sc_addr))
 			return FALSE;
 	}
 
@@ -1436,10 +1452,10 @@ const guint8 *sms_extract_common(const struct sms *sms, gboolean *out_udhi,
 					guint8 *out_max)
 {
 	const guint8 *ud = NULL;
-	guint8 udl;
-	guint8 max;
-	gboolean udhi;
-	guint8 dcs;
+	guint8 uninitialized_var(udl);
+	guint8 uninitialized_var(max);
+	gboolean uninitialized_var(udhi);
+	guint8 uninitialized_var(dcs);
 
 	switch (sms->type) {
 	case SMS_TYPE_DELIVER:
@@ -1753,7 +1769,7 @@ static gboolean extract_app_port_common(struct sms_udh_iter *iter, int *dst,
 	guint8 addr_hdr[4];
 	int srcport = -1;
 	int dstport = -1;
-	gboolean is_addr_8bit;
+	gboolean uninitialized_var(is_addr_8bit);
 
 	/* According to the specification, we have to use the last
 	 * useable header.  Also, we have to ignore ports that are reserved:
@@ -1839,8 +1855,8 @@ gboolean sms_extract_concatenation(const struct sms *sms, guint16 *ref_num,
 	struct sms_udh_iter iter;
 	enum sms_iei iei;
 	guint8 concat_hdr[4];
-	guint16 rn;
-	guint8 max, seq;
+	guint16 uninitialized_var(rn);
+	guint8 uninitialized_var(max), uninitialized_var(seq);
 	gboolean concatenated = FALSE;
 
 	/* We must ignore the entire user_data header here:
@@ -2269,7 +2285,6 @@ GSList *sms_text_prepare(const char *utf8, guint16 ref,
 	long written;
 	long left;
 	guint8 seq;
-	guint8 max;
 	GSList *r = NULL;
 
 	memset(&template, 0, sizeof(struct sms));
@@ -2701,13 +2716,16 @@ char *cbs_decode_text(GSList *cbs_list, char *iso639_lang)
 {
 	GSList *l;
 	const struct cbs *cbs = cbs_list->data;
-	enum sms_charset charset;
+	enum sms_charset uninitialized_var(charset);
 	enum cbs_language lang;
-	gboolean iso639;
+	gboolean uninitialized_var(iso639);
 	int bufsize = 0;
 	unsigned char *buf;
 	char *utf8;
 
+	if (cbs_list == NULL)
+		return NULL;
+
 	/* CBS can only come from the network, so we're much less lenient
 	 * on what we support.  Namely we require the same charset to be
 	 * used across all pages.
@@ -2761,7 +2779,8 @@ char *cbs_decode_text(GSList *cbs_list, char *iso639_lang)
 
 			unpack_7bit_own_buf(cbs->ud + taken, 82 - taken,
 						taken, FALSE, 2,
-						NULL, 0, iso639_lang);
+						NULL, 0,
+						(unsigned char *)iso639_lang);
 			iso639_lang[2] = '\0';
 		} else
 			iso639_2_from_language(lang, iso639_lang);
@@ -2842,8 +2861,8 @@ char *cbs_decode_text(GSList *cbs_list, char *iso639_lang)
 	if (charset == SMS_CHARSET_7BIT)
 		utf8 = convert_gsm_to_utf8(buf, bufsize, NULL, NULL, 0);
 	else
-		utf8 = g_convert(buf, bufsize, "UTF-8//TRANSLIT", "UCS-2BE",
-					NULL, NULL, NULL);
+		utf8 = g_convert((char *)buf, bufsize, "UTF-8//TRANSLIT",
+					"UCS-2BE", NULL, NULL, NULL);
 
 	g_free(buf);
 	return utf8;
