@@ -27,7 +27,6 @@
 #include <stdio.h>
 #include <time.h>
 
-#include <dbus/dbus.h>
 #include <glib.h>
 #include <gdbus.h>
 
@@ -35,8 +34,6 @@
 
 #include "driver.h"
 #include "common.h"
-#include "dbus-gsm.h"
-#include "modem.h"
 #include "cssn.h"
 
 #define VOICECALL_MANAGER_INTERFACE "org.ofono.VoiceCallManager"
@@ -44,8 +41,6 @@
 
 #define VOICECALLS_FLAG_PENDING 0x1
 #define VOICECALLS_FLAG_MULTI_RELEASE 0x2
-#define VOICECALLS_FLAG_UPDATING_CALL_LIST 0x4
-#define VOICECALLS_FLAG_UPDATING_MPTY_CALL_LIST 0x8
 
 #define MAX_VOICE_CALLS 16
 
@@ -56,6 +51,8 @@ struct voicecalls_data {
 	struct ofono_voicecall_ops *ops;
 	int flags;
 	DBusMessage *pending;
+	gint emit_calls_source;
+	gint emit_multi_source;
 };
 
 struct voicecall {
@@ -165,12 +162,12 @@ static DBusMessage *voicecall_get_properties(DBusConnection *conn,
 	dbus_message_iter_init_append(reply, &iter);
 
 	dbus_message_iter_open_container(&iter, DBUS_TYPE_ARRAY,
-						PROPERTIES_ARRAY_SIGNATURE,
-						&dict);
+					OFONO_PROPERTIES_ARRAY_SIGNATURE,
+					&dict);
 
-	dbus_gsm_dict_append(&dict, "State", DBUS_TYPE_STRING, &status);
+	ofono_dbus_dict_append(&dict, "State", DBUS_TYPE_STRING, &status);
 
-	dbus_gsm_dict_append(&dict, "LineIdentification",
+	ofono_dbus_dict_append(&dict, "LineIdentification",
 				DBUS_TYPE_STRING, &callerid);
 
 	if (call->status == CALL_STATUS_ACTIVE ||
@@ -178,7 +175,7 @@ static DBusMessage *voicecall_get_properties(DBusConnection *conn,
 		call->status == CALL_STATUS_HELD) {
 		timestr = time_to_str(&v->start_time);
 
-		dbus_gsm_dict_append(&dict, "StartTime", DBUS_TYPE_STRING,
+		ofono_dbus_dict_append(&dict, "StartTime", DBUS_TYPE_STRING,
 					&timestr);
 	}
 
@@ -197,13 +194,13 @@ static DBusMessage *voicecall_busy(DBusConnection *conn,
 
 	if (call->status != CALL_STATUS_INCOMING &&
 		call->status != CALL_STATUS_WAITING)
-		return dbus_gsm_failed(msg);
+		return __ofono_error_failed(msg);
 
 	if (!voicecalls->ops->set_udub)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	if (voicecalls->flags & VOICECALLS_FLAG_PENDING)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	voicecalls->flags |= VOICECALLS_FLAG_PENDING;
 	voicecalls->pending = dbus_message_ref(msg);
@@ -226,20 +223,20 @@ static DBusMessage *voicecall_deflect(DBusConnection *conn,
 
 	if (call->status != CALL_STATUS_INCOMING &&
 		call->status != CALL_STATUS_WAITING)
-		return dbus_gsm_failed(msg);
+		return __ofono_error_failed(msg);
 
 	if (!voicecalls->ops->deflect)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	if (voicecalls->flags & VOICECALLS_FLAG_PENDING)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (dbus_message_get_args(msg, NULL, DBUS_TYPE_STRING, &number,
 					DBUS_TYPE_INVALID) == FALSE)
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	if (!valid_phone_number_format(number))
-		return dbus_gsm_invalid_format(msg);
+		return __ofono_error_invalid_format(msg);
 
 	voicecalls->flags |= VOICECALLS_FLAG_PENDING;
 	voicecalls->pending = dbus_message_ref(msg);
@@ -260,13 +257,13 @@ static DBusMessage *voicecall_hangup(DBusConnection *conn,
 	struct ofono_call *call = v->call;
 
 	if (call->status == CALL_STATUS_DISCONNECTED)
-		return dbus_gsm_failed(msg);
+		return __ofono_error_failed(msg);
 
 	if (!voicecalls->ops->release_specific)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	if (voicecalls->flags & VOICECALLS_FLAG_PENDING)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	voicecalls->flags |= VOICECALLS_FLAG_PENDING;
 	voicecalls->pending = dbus_message_ref(msg);
@@ -286,13 +283,13 @@ static DBusMessage *voicecall_answer(DBusConnection *conn,
 	struct ofono_call *call = v->call;
 
 	if (call->status != CALL_STATUS_INCOMING)
-		return dbus_gsm_failed(msg);
+		return __ofono_error_failed(msg);
 
 	if (!voicecalls->ops->answer)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	if (voicecalls->flags & VOICECALLS_FLAG_PENDING)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	voicecalls->flags |= VOICECALLS_FLAG_PENDING;
 	voicecalls->pending = dbus_message_ref(msg);
@@ -349,9 +346,9 @@ static void voicecall_destroy(gpointer userdata)
 static const char *voicecall_build_path(struct ofono_modem *modem,
 					const struct ofono_call *call)
 {
-	static char path[MAX_DBUS_PATH_LEN];
+	static char path[256];
 
-	snprintf(path, MAX_DBUS_PATH_LEN, "%s/voicecall%02d",
+	snprintf(path, sizeof(path), "%s/voicecall%02d",
 			modem->path, call->id);
 
 	return path;
@@ -361,7 +358,7 @@ static void voicecall_set_call_status(struct ofono_modem *modem,
 					struct voicecall *call,
 					int status)
 {
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	const char *path;
 	const char *status_str;
 	int old_status;
@@ -376,7 +373,7 @@ static void voicecall_set_call_status(struct ofono_modem *modem,
 	status_str = call_status_to_string(status);
 	path = voicecall_build_path(modem, call->call);
 
-	dbus_gsm_signal_property_changed(conn, path, VOICECALL_INTERFACE,
+	ofono_dbus_signal_property_changed(conn, path, VOICECALL_INTERFACE,
 						"State", DBUS_TYPE_STRING,
 						&status_str);
 
@@ -390,7 +387,7 @@ static void voicecall_set_call_status(struct ofono_modem *modem,
 		call->start_time = time(NULL);
 		timestr = time_to_str(&call->start_time);
 
-		dbus_gsm_signal_property_changed(conn, path,
+		ofono_dbus_signal_property_changed(conn, path,
 							VOICECALL_INTERFACE,
 							"StartTime",
 							DBUS_TYPE_STRING,
@@ -404,7 +401,7 @@ static void voicecall_set_call_lineid(struct ofono_modem *modem,
 					int clip_validity)
 {
 	struct ofono_call *call = v->call;
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	const char *path;
 	const char *lineid_str;
 
@@ -434,14 +431,14 @@ static void voicecall_set_call_lineid(struct ofono_modem *modem,
 	else
 		lineid_str = phone_number_to_string(ph);
 
-	dbus_gsm_signal_property_changed(conn, path, VOICECALL_INTERFACE,
+	ofono_dbus_signal_property_changed(conn, path, VOICECALL_INTERFACE,
 						"LineIdentification",
 						DBUS_TYPE_STRING, &lineid_str);
 }
 
 static gboolean voicecall_dbus_register(struct voicecall *voicecall)
 {
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	const char *path;
 
 	if (!voicecall)
@@ -466,7 +463,7 @@ static gboolean voicecall_dbus_register(struct voicecall *voicecall)
 static gboolean voicecall_dbus_unregister(struct ofono_modem *modem,
 						struct voicecall *call)
 {
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	const char *path = voicecall_build_path(modem, call->call);
 
 	return g_dbus_unregister_interface(conn, path,
@@ -488,6 +485,16 @@ static void voicecalls_destroy(gpointer userdata)
 	struct voicecalls_data *calls = modem->voicecalls;
 	GSList *l;
 
+	if (calls->emit_calls_source) {
+		g_source_remove(calls->emit_calls_source);
+		calls->emit_calls_source = 0;
+	}
+
+	if (calls->emit_multi_source) {
+		g_source_remove(calls->emit_multi_source);
+		calls->emit_multi_source = 0;
+	}
+
 	for (l = calls->call_list; l; l = l->next)
 		voicecall_dbus_unregister(modem, l->data);
 
@@ -708,21 +715,22 @@ static DBusMessage *manager_get_properties(DBusConnection *conn,
 	dbus_message_iter_init_append(reply, &iter);
 
 	dbus_message_iter_open_container(&iter, DBUS_TYPE_ARRAY,
-					PROPERTIES_ARRAY_SIGNATURE, &dict);
+					OFONO_PROPERTIES_ARRAY_SIGNATURE,
+					&dict);
 
 	voicecalls_path_list(modem, calls->call_list, &callobj_list);
 
-	dbus_gsm_dict_append_array(&dict, "Calls", DBUS_TYPE_OBJECT_PATH,
+	ofono_dbus_dict_append_array(&dict, "Calls", DBUS_TYPE_OBJECT_PATH,
 				&callobj_list);
 
-	dbus_gsm_free_string_array(callobj_list);
+	g_strfreev(callobj_list);
 
 	voicecalls_path_list(modem, calls->multiparty_list, &callobj_list);
 
-	dbus_gsm_dict_append_array(&dict, "MultipartyCalls",
+	ofono_dbus_dict_append_array(&dict, "MultipartyCalls",
 					DBUS_TYPE_OBJECT_PATH, &callobj_list);
 
-	dbus_gsm_free_string_array(callobj_list);
+	g_strfreev(callobj_list);
 
 	dbus_message_iter_close_container(&iter, &dict);
 
@@ -740,18 +748,18 @@ static DBusMessage *manager_dial(DBusConnection *conn,
 	enum ofono_clir_option clir;
 
 	if (calls->flags & VOICECALLS_FLAG_PENDING)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (g_slist_length(calls->call_list) >= MAX_VOICE_CALLS)
-		return dbus_gsm_failed(msg);
+		return __ofono_error_failed(msg);
 
 	if (dbus_message_get_args(msg, NULL, DBUS_TYPE_STRING, &number,
 					DBUS_TYPE_STRING, &clirstr,
 					DBUS_TYPE_INVALID) == FALSE)
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	if (!valid_phone_number_format(number))
-		return dbus_gsm_invalid_format(msg);
+		return __ofono_error_invalid_format(msg);
 
 	if (strlen(clirstr) == 0 || !strcmp(clirstr, "default"))
 		clir = OFONO_CLIR_OPTION_DEFAULT;
@@ -760,14 +768,14 @@ static DBusMessage *manager_dial(DBusConnection *conn,
 	else if (!strcmp(clirstr, "enabled"))
 		clir = OFONO_CLIR_OPTION_INVOCATION;
 	else
-		return dbus_gsm_invalid_format(msg);
+		return __ofono_error_invalid_format(msg);
 
 	if (!calls->ops->dial)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	if (voicecalls_have_active(calls) &&
 		voicecalls_have_held(calls))
-		return dbus_gsm_failed(msg);
+		return __ofono_error_failed(msg);
 
 	calls->flags |= VOICECALLS_FLAG_PENDING;
 	calls->pending = dbus_message_ref(msg);
@@ -789,7 +797,7 @@ static DBusMessage *manager_transfer(DBusConnection *conn,
 	int numheld;
 
 	if (calls->flags & VOICECALLS_FLAG_PENDING)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	numactive = voicecalls_num_active(calls);
 
@@ -802,10 +810,10 @@ static DBusMessage *manager_transfer(DBusConnection *conn,
 	numheld = voicecalls_num_held(calls);
 
 	if ((numactive != 1) && (numheld != 1))
-		return dbus_gsm_failed(msg);
+		return __ofono_error_failed(msg);
 
 	if (!calls->ops->transfer)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	calls->flags |= VOICECALLS_FLAG_PENDING;
 	calls->pending = dbus_message_ref(msg);
@@ -822,13 +830,13 @@ static DBusMessage *manager_swap_calls(DBusConnection *conn,
 	struct voicecalls_data *calls = modem->voicecalls;
 
 	if (calls->flags & VOICECALLS_FLAG_PENDING)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (voicecalls_have_waiting(calls))
-		return dbus_gsm_failed(msg);
+		return __ofono_error_failed(msg);
 
 	if (!calls->ops->hold_all_active)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	calls->flags |= VOICECALLS_FLAG_PENDING;
 	calls->pending = dbus_message_ref(msg);
@@ -845,13 +853,13 @@ static DBusMessage *manager_release_and_answer(DBusConnection *conn,
 	struct voicecalls_data *calls = modem->voicecalls;
 
 	if (calls->flags & VOICECALLS_FLAG_PENDING)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (!voicecalls_have_active(calls) || !voicecalls_have_waiting(calls))
-		return dbus_gsm_failed(msg);
+		return __ofono_error_failed(msg);
 
 	if (!calls->ops->release_all_active)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	calls->flags |= VOICECALLS_FLAG_PENDING;
 	calls->pending = dbus_message_ref(msg);
@@ -868,14 +876,14 @@ static DBusMessage *manager_hold_and_answer(DBusConnection *conn,
 	struct voicecalls_data *calls = modem->voicecalls;
 
 	if (calls->flags & VOICECALLS_FLAG_PENDING)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (voicecalls_have_active(calls) && voicecalls_have_held(calls) &&
 		voicecalls_have_waiting(calls))
-		return dbus_gsm_failed(msg);
+		return __ofono_error_failed(msg);
 
 	if (!calls->ops->hold_all_active)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	calls->flags |= VOICECALLS_FLAG_PENDING;
 	calls->pending = dbus_message_ref(msg);
@@ -892,12 +900,12 @@ static DBusMessage *manager_hangup_all(DBusConnection *conn,
 	struct voicecalls_data *calls = modem->voicecalls;
 
 	if (calls->flags & VOICECALLS_FLAG_PENDING)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (!calls->ops->release_specific)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
-	if (g_slist_length(calls->call_list) == 0) {
+	if (calls->call_list == NULL) {
 		DBusMessage *reply = dbus_message_new_method_return(msg);
 		return reply;
 	}
@@ -924,22 +932,22 @@ static DBusMessage *multiparty_private_chat(DBusConnection *conn,
 	GSList *l;
 
 	if (calls->flags & VOICECALLS_FLAG_PENDING)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (dbus_message_get_args(msg, NULL, DBUS_TYPE_OBJECT_PATH, &callpath,
 					DBUS_TYPE_INVALID) == FALSE)
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
-	if (strlen(callpath) == 0 || strlen(callpath) > MAX_DBUS_PATH_LEN)
-		return dbus_gsm_invalid_format(msg);
+	if (strlen(callpath) == 0)
+		return __ofono_error_invalid_format(msg);
 
 	c = strrchr(callpath, '/');
 
 	if (!c || strncmp(modem->path, callpath, c-callpath))
-		return dbus_gsm_not_found(msg);
+		return __ofono_error_not_found(msg);
 
 	if (!sscanf(c, "/voicecall%2u", &id))
-		return dbus_gsm_not_found(msg);
+		return __ofono_error_not_found(msg);
 
 	for (l = calls->multiparty_list; l; l = l->next) {
 		struct voicecall *v = l->data;
@@ -948,17 +956,17 @@ static DBusMessage *multiparty_private_chat(DBusConnection *conn,
 	}
 
 	if (!l)
-		return dbus_gsm_not_found(msg);
+		return __ofono_error_not_found(msg);
 
 	/* If we found id on the list of multiparty calls, then by definition
 	 * the multiparty call exists.	Only thing to check is whether we have
 	 * held calls
 	 */
 	if (voicecalls_have_held(calls))
-		return dbus_gsm_failed(msg);
+		return __ofono_error_failed(msg);
 
 	if (!calls->ops->private_chat)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	calls->flags |= VOICECALLS_FLAG_PENDING;
 	calls->pending = dbus_message_ref(msg);
@@ -975,13 +983,13 @@ static DBusMessage *multiparty_create(DBusConnection *conn,
 	struct voicecalls_data *calls = modem->voicecalls;
 
 	if (calls->flags & VOICECALLS_FLAG_PENDING)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (!voicecalls_have_held(calls) || !voicecalls_have_active(calls))
-		return dbus_gsm_failed(msg);
+		return __ofono_error_failed(msg);
 
 	if (!calls->ops->create_multiparty)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	calls->flags |= VOICECALLS_FLAG_PENDING;
 	calls->pending = dbus_message_ref(msg);
@@ -998,18 +1006,18 @@ static DBusMessage *multiparty_hangup(DBusConnection *conn,
 	struct voicecalls_data *calls = modem->voicecalls;
 
 	if (calls->flags & VOICECALLS_FLAG_PENDING)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (!calls->ops->release_specific)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	if (!calls->ops->release_all_held)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	if (!calls->ops->release_all_active)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
-	if (g_slist_length(calls->multiparty_list) == 0) {
+	if (calls->multiparty_list == NULL) {
 		DBusMessage *reply = dbus_message_new_method_return(msg);
 		return reply;
 	}
@@ -1057,23 +1065,23 @@ static DBusMessage *manager_tone(DBusConnection *conn,
 	int i, len;
 
 	if (calls->flags & VOICECALLS_FLAG_PENDING)
-		return dbus_gsm_busy(msg);
+		return __ofono_error_busy(msg);
 
 	if (!calls->ops->send_tones)
-		return dbus_gsm_not_implemented(msg);
+		return __ofono_error_not_implemented(msg);
 
 	/* Send DTMFs only if we have at least one connected call */
 	if (!voicecalls_have_connected(calls))
-		return dbus_gsm_failed(msg);
+		return __ofono_error_failed(msg);
 
 	if (dbus_message_get_args(msg, NULL, DBUS_TYPE_STRING, &in_tones,
 					DBUS_TYPE_INVALID) == FALSE)
-		return dbus_gsm_invalid_args(msg);
+		return __ofono_error_invalid_args(msg);
 
 	len = strlen(in_tones);
 
 	if (len == 0)
-		return dbus_gsm_invalid_format(msg);
+		return __ofono_error_invalid_format(msg);
 
 	tones = g_ascii_strup(in_tones, len);
 
@@ -1085,7 +1093,7 @@ static DBusMessage *manager_tone(DBusConnection *conn,
 			continue;
 
 		g_free(tones);
-		return dbus_gsm_invalid_format(msg);
+		return __ofono_error_invalid_format(msg);
 	}
 
 	calls->flags |= VOICECALLS_FLAG_PENDING;
@@ -1132,21 +1140,20 @@ static gboolean real_emit_call_list_changed(void *data)
 {
 	struct ofono_modem *modem = data;
 	struct voicecalls_data *voicecalls = modem->voicecalls;
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	char **objpath_list;
 
 	voicecalls_path_list(modem, voicecalls->call_list, &objpath_list);
 
-	dbus_gsm_signal_array_property_changed(conn, modem->path,
+	ofono_dbus_signal_array_property_changed(conn, modem->path,
 				VOICECALL_MANAGER_INTERFACE,
 				"Calls",
 				DBUS_TYPE_OBJECT_PATH,
 				&objpath_list);
 
-	dbus_gsm_free_string_array(objpath_list);
+	g_strfreev(objpath_list);
 
-	ofono_debug("Resetting updating flag");
-	voicecalls->flags &= ~VOICECALLS_FLAG_UPDATING_CALL_LIST;
+	voicecalls->emit_calls_source = 0;
 
 	return FALSE;
 }
@@ -1156,10 +1163,9 @@ static void emit_call_list_changed(struct ofono_modem *modem)
 #ifdef DELAY_EMIT
 	struct voicecalls_data *calls = modem->voicecalls;
 
-	if (!(calls->flags & VOICECALLS_FLAG_UPDATING_CALL_LIST)) {
-		calls->flags |= VOICECALLS_FLAG_UPDATING_CALL_LIST;
-		g_timeout_add(0, real_emit_call_list_changed, modem);
-	}
+	if (calls->emit_calls_source == 0)
+		calls->emit_calls_source = 
+			g_timeout_add(0, real_emit_call_list_changed, modem);
 #else
 	real_emit_call_list_changed(modem);
 #endif
@@ -1169,19 +1175,19 @@ static gboolean real_emit_multiparty_call_list_changed(void *data)
 {
 	struct ofono_modem *modem = data;
 	struct voicecalls_data *voicecalls = modem->voicecalls;
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	char **objpath_list;
 
 	voicecalls_path_list(modem, voicecalls->multiparty_list, &objpath_list);
 
-	dbus_gsm_signal_array_property_changed(conn, modem->path,
+	ofono_dbus_signal_array_property_changed(conn, modem->path,
 				VOICECALL_MANAGER_INTERFACE, "MultipartyCalls",
 				DBUS_TYPE_OBJECT_PATH,
 				&objpath_list);
 
-	dbus_gsm_free_string_array(objpath_list);
-
-	voicecalls->flags &= ~VOICECALLS_FLAG_UPDATING_MPTY_CALL_LIST;
+	g_strfreev(objpath_list);
+	
+	voicecalls->emit_multi_source = 0;
 
 	return FALSE;
 }
@@ -1191,9 +1197,9 @@ static void emit_multiparty_call_list_changed(struct ofono_modem *modem)
 #ifdef DELAY_EMIT
 	struct voicecalls_data *calls = modem->voicecalls;
 
-	if (!(calls->flags & VOICECALLS_FLAG_UPDATING_MPTY_CALL_LIST)) {
-		calls->flags |= VOICECALLS_FLAG_UPDATING_MPTY_CALL_LIST;
-		g_timeout_add(0, real_emit_multiparty_call_list_changed, modem);
+	if (calls->emit_multi_source == 0)
+		calls->emit_multi_source = g_timeout_add(0, 
+				real_emit_multiparty_call_list_changed, modem);
 	}
 #else
 	real_emit_multiparty_call_list_changed(modem);
@@ -1243,15 +1249,15 @@ void ofono_voicecall_disconnected(struct ofono_modem *modem, int id,
 
 	calls->release_list = g_slist_remove(calls->release_list, call);
 
-	modem_release_callid(modem, id);
+	__ofono_modem_release_callid(modem, id);
 
 	/* TODO: Emit disconnect reason */
 	voicecall_set_call_status(modem, call, CALL_STATUS_DISCONNECTED);
 
 	if (prev_status == CALL_STATUS_INCOMING)
-		ofono_history_call_missed(modem, call->call, ts);
+		__ofono_history_call_missed(modem, call->call, ts);
 	else
-		ofono_history_call_ended(modem, call->call,
+		__ofono_history_call_ended(modem, call->call,
 						call->detect_time, ts);
 
 	voicecall_dbus_unregister(modem, call);
@@ -1294,7 +1300,7 @@ void ofono_voicecall_notify(struct ofono_modem *modem, const struct ofono_call *
 
 	memcpy(newcall, call, sizeof(struct ofono_call));
 
-	if (modem_alloc_callid(modem) != call->id) {
+	if (__ofono_modem_alloc_callid(modem) != call->id) {
 		ofono_error("Warning: Call id and internally tracked id"
 				" do not correspond");
 		goto err;
@@ -1332,7 +1338,7 @@ err:
 static void generic_callback(const struct ofono_error *error, void *data)
 {
 	struct voicecalls_data *calls = data;
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	DBusMessage *reply;
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR)
@@ -1347,7 +1353,7 @@ static void generic_callback(const struct ofono_error *error, void *data)
 	if (error->type == OFONO_ERROR_TYPE_NO_ERROR)
 		reply = dbus_message_new_method_return(calls->pending);
 	else
-		reply = dbus_gsm_failed(calls->pending);
+		reply = __ofono_error_failed(calls->pending);
 
 	g_dbus_send_message(conn, reply);
 
@@ -1359,10 +1365,10 @@ static void multirelease_callback(const struct ofono_error *error, void *data)
 {
 	struct ofono_modem *modem = data;
 	struct voicecalls_data *calls = modem->voicecalls;
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	DBusMessage *reply;
 
-	if (g_slist_length(calls->release_list)) {
+	if (calls->release_list != NULL) {
 		voicecalls_release_next(modem);
 		return;
 	}
@@ -1392,7 +1398,7 @@ static struct ofono_call *synthesize_outgoing_call(struct ofono_modem *modem,
 	if (!call)
 		return call;
 
-	call->id = modem_alloc_callid(modem);
+	call->id = __ofono_modem_alloc_callid(modem);
 
 	if (call->id == 0) {
 		ofono_error("Failed to alloc callid, too many calls");
@@ -1417,7 +1423,7 @@ static void dial_callback(const struct ofono_error *error, void *data)
 {
 	struct ofono_modem *modem = data;
 	struct voicecalls_data *calls = modem->voicecalls;
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	DBusMessage *reply;
 	GSList *l;
 	struct ofono_call *call;
@@ -1434,7 +1440,7 @@ static void dial_callback(const struct ofono_error *error, void *data)
 		return;
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
-		reply = dbus_gsm_failed(calls->pending);
+		reply = __ofono_error_failed(calls->pending);
 		g_dbus_send_message(conn, reply);
 
 		goto out;
@@ -1459,7 +1465,7 @@ static void dial_callback(const struct ofono_error *error, void *data)
 		call = synthesize_outgoing_call(modem, calls->pending);
 
 		if (!call) {
-			reply = dbus_gsm_failed(calls->pending);
+			reply = __ofono_error_failed(calls->pending);
 			g_dbus_send_message(conn, reply);
 
 			goto out;
@@ -1468,7 +1474,7 @@ static void dial_callback(const struct ofono_error *error, void *data)
 		v = voicecall_create(modem, call);
 
 		if (!v) {
-			reply = dbus_gsm_failed(calls->pending);
+			reply = __ofono_error_failed(calls->pending);
 			g_dbus_send_message(conn, reply);
 
 			goto out;
@@ -1531,7 +1537,7 @@ static void multiparty_create_callback(const struct ofono_error *error, void *da
 {
 	struct ofono_modem *modem = data;
 	struct voicecalls_data *calls = modem->voicecalls;
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	DBusMessage *reply;
 	gboolean need_to_emit = FALSE;
 
@@ -1545,7 +1551,7 @@ static void multiparty_create_callback(const struct ofono_error *error, void *da
 		return;
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
-		reply = dbus_gsm_failed(calls->pending);
+		reply = __ofono_error_failed(calls->pending);
 		goto out;
 	}
 
@@ -1570,7 +1576,7 @@ static void multiparty_create_callback(const struct ofono_error *error, void *da
 		ofono_error("Created multiparty call, but size is less than 2"
 				" panic!");
 
-		reply = dbus_gsm_failed(calls->pending);
+		reply = __ofono_error_failed(calls->pending);
 	} else {
 		reply = dbus_message_new_method_return(calls->pending);
 
@@ -1592,7 +1598,7 @@ static void private_chat_callback(const struct ofono_error *error, void *data)
 {
 	struct ofono_modem *modem = data;
 	struct voicecalls_data *calls = modem->voicecalls;
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 	DBusMessage *reply;
 	gboolean need_to_emit = FALSE;
 	const char *callpath;
@@ -1610,7 +1616,7 @@ static void private_chat_callback(const struct ofono_error *error, void *data)
 		return;
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
-		reply = dbus_gsm_failed(calls->pending);
+		reply = __ofono_error_failed(calls->pending);
 		goto out;
 	}
 
@@ -1651,7 +1657,7 @@ out:
 
 int ofono_voicecall_register(struct ofono_modem *modem, struct ofono_voicecall_ops *ops)
 {
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 
 	if (modem == NULL)
 		return -1;
@@ -1678,19 +1684,19 @@ int ofono_voicecall_register(struct ofono_modem *modem, struct ofono_voicecall_o
 		return -1;
 	}
 
-	modem_add_interface(modem, VOICECALL_MANAGER_INTERFACE);
+	ofono_modem_add_interface(modem, VOICECALL_MANAGER_INTERFACE);
 
 	return 0;
 }
 
 void ofono_voicecall_unregister(struct ofono_modem *modem)
 {
-	DBusConnection *conn = dbus_gsm_connection();
+	DBusConnection *conn = ofono_dbus_get_connection();
 
 	if (!modem->voicecalls)
 		return;
 
-	modem_remove_interface(modem, VOICECALL_MANAGER_INTERFACE);
+	ofono_modem_remove_interface(modem, VOICECALL_MANAGER_INTERFACE);
 	g_dbus_unregister_interface(conn, modem->path,
 					VOICECALL_MANAGER_INTERFACE);
 
